@@ -38,6 +38,13 @@ def run(argv=None):
                         required=True,
                         help='Output file to write results to')
 
+    parser.add_argument('--multi-input',
+                        type=bool,
+                        dest='multi_input',
+                        required=False,
+                        default=False,
+                        help='True if multiple inputs. The corresponding file pattern will be appended.')
+
     parser.add_argument('--google-application-credentials',
                         type=str,
                         dest='google_application_credentials',
@@ -57,7 +64,8 @@ def run(argv=None):
     pipeline_options = PipelineOptions(pipeline_args)
 
     with beam.Pipeline(options=pipeline_options) as p:
-        lines = p | 'ReadFromText' >> ReadFromText(known_args.input)
+        filepattern_suffix = "/*" if known_args.multi_input else ""
+        lines = p | 'ReadFromText' >> ReadFromText(known_args.input + filepattern_suffix)
 
         jsonsGroupedBySchema = (lines
                                 | 'JSONLoads' >> beam.Map(json.loads)
